## 3.0.1 (2022-03-19)

Add mypy error codes to `type: ignore`s, remove unused ignores (#7504)

Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

## 3.0.0 (2022-03-07)

Add openpyxl stubs (#6801)

